#[non_exhaustive]pub enum RtcpWriteError {
Show 21 variants
OutputTooSmall(usize),
InvalidPadding {
padding: u8,
},
AppSubtypeOutOfRange {
subtype: u8,
max: u8,
},
InvalidName,
DataLen32bitMultiple(usize),
TooManySources {
count: usize,
max: u8,
},
ReasonLenTooLarge {
len: usize,
max: u8,
},
CumulativeLostTooLarge {
value: u32,
max: u32,
},
TooManyReportBlocks {
count: usize,
max: u8,
},
TooManySdesChunks {
count: usize,
max: u8,
},
SdesValueTooLarge {
len: usize,
max: u8,
},
SdesPrivPrefixTooLarge {
len: usize,
max: u8,
},
CountOutOfRange {
count: u8,
max: u8,
},
NonLastCompoundPacketPadding,
MissingFci,
TooManyNack,
FciWrongFeedbackPacketType,
PayloadTypeInvalid,
PaddingBitsTooLarge,
TooManyFir,
TwccReferenceTimeTooLarge,
}Expand description
Errors produced when writing a packet
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
OutputTooSmall(usize)
Output buffer is not large enough to fit the resulting buffer. The requested size is returned.
InvalidPadding
The provided padding is not a multiple of 4.
AppSubtypeOutOfRange
App Subtype was out of range.
InvalidName
APP Packet Name is invalid. Expecting a sequence of four ASCII characters.
DataLen32bitMultiple(usize)
Data length must be a mutliple of 32bits. The data length is returned.
TooManySources
Too many Sources specified.
ReasonLenTooLarge
Reason length was too large.
CumulativeLostTooLarge
Cumulative Lost was too large.
TooManyReportBlocks
Too many Report Blocks specified (max 31).
TooManySdesChunks
Too many SDES Chunks specified.
SdesValueTooLarge
SDES Value length was too large.
Fields
SdesPrivPrefixTooLarge
The SDES PRIV prefix was too large.
Fields
CountOutOfRange
Unknown Count was out of range.
NonLastCompoundPacketPadding
Non-last Compound packet padding defined.
MissingFci
Feedback packet does not have any FCI defined.
TooManyNack
Number of NACK’s will not fit within a single RTCP packet.
FciWrongFeedbackPacketType
Feedback packet does not support this FCI data.
PayloadTypeInvalid
Payload type value out of range.
PaddingBitsTooLarge
Payload type value out of range.
TooManyFir
Number of FIR’s will not fit within a single RTCP packet.
TwccReferenceTimeTooLarge
reference time passed to TwccBuilder does not fit into 24 bits.