pub struct SdesChunkBuilder<'a> { /* private fields */ }Expand description
SDES Chunk Builder
Implementations
Sourceimpl<'a> SdesChunkBuilder<'a>
impl<'a> SdesChunkBuilder<'a>
Sourcepub fn add_item(self, item: SdesItemBuilder<'a>) -> Self
pub fn add_item(self, item: SdesItemBuilder<'a>) -> Self
Add an item to this chunk
Sourcepub fn write_into(&self, buf: &mut [u8]) -> Result<usize, RtcpWriteError>
pub fn write_into(&self, buf: &mut [u8]) -> Result<usize, RtcpWriteError>
Writes the SDES Chunk into buf.
Returns an error if:
- The buffer is too small.
- An Item generated an error.
Sourcepub fn add_item_owned(self, item: SdesItemBuilder<'_>) -> Self
pub fn add_item_owned(self, item: SdesItemBuilder<'_>) -> Self
Adds an item transforming it into an owned version first.
Lifetime of self is unchanged even if item is shorter lived.